@@ -139,6 +139,9 @@ class OvnProviderDriver(driver_base.ProviderDriver):
             self.health_monitor_create(pool.healthmonitor)
 
     def pool_delete(self, pool):
+        if pool.healthmonitor:
+            self.health_monitor_delete(pool.healthmonitor)
+
         for member in pool.members:
             self.member_delete(member)
 
@@ -319,25 +322,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def member_update(self, old_member, new_member):
-        # NOTE(froyo): OVN provider allow to create member without param
-        # subnet_id, in that case the driver search it according to the
-        # pool_id, but it is not propagated to Octavia. In this case, if
-        # the member is updated, Octavia send the object without subnet_id.
-        subnet_id = old_member.subnet_id
-        if (isinstance(subnet_id, o_datamodels.UnsetType) or not subnet_id):
-            subnet_id, subnet_cidr = self._ovn_helper._get_subnet_from_pool(
-                old_member.pool_id)
-            if not (subnet_id and
-                    self._ovn_helper._check_ip_in_subnet(new_member.address,
-                                                         subnet_cidr)):
-                msg = _('Subnet is required, or Loadbalancer associated with '
-                        'Pool must have a subnet, for Member update '
-                        'with OVN Provider Driver if it is not the same as '
-                        'LB VIP subnet')
-                raise driver_exceptions.UnsupportedOptionError(
-                    user_fault_string=msg,
-                    operator_fault_string=msg)
-
         # Validate monitoring options if present
         self._check_member_monitor_options(new_member)
         if new_member.address and self._ip_version_differs(new_member):
@@ -346,7 +330,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'address': old_member.address,
                         'protocol_port': old_member.protocol_port,
                         'pool_id': old_member.pool_id,
-                        'subnet_id': subnet_id,
                         'old_admin_state_up': old_member.admin_state_up}
         if not isinstance(new_member.admin_state_up, o_datamodels.UnsetType):
             request_info['admin_state_up'] = new_member.admin_state_up
@@ -356,7 +339,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
     def member_batch_update(self, pool_id, members):
         request_list = []
-        skipped_members = []
         pool_key, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(pool_id)
         external_ids = copy.deepcopy(ovn_lb.external_ids)
         pool = external_ids[pool_key]
@@ -364,10 +346,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         members_to_delete = copy.copy(existing_members)
         pool_subnet_id = None
         for member in members:
-            if (self._check_monitor_options(member) or
-                    member.address and self._ip_version_differs(member)):
-                skipped_members.append(member.member_id)
-                continue
+            # NOTE(froyo): in order to keep sync with Octavia DB, we raise
+            # not supporting exceptions as soon as posible, considering the
+            # full request as not valid
+            if (self._check_monitor_options(member)):
+                msg = 'OVN provider does not support monitor options'
+                raise driver_exceptions.UnsupportedOptionError(
+                    user_fault_string=msg,
+                    operator_fault_string=msg)
+            if (member.address and self._ip_version_differs(member)):
+                raise ovn_exc.IPVersionsMixingNotSupportedError()
             # NOTE(froyo): if subnet_id not provided, lets try to get it
             # from the member pool_id
             subnet_id = member.subnet_id
@@ -415,7 +403,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
         for member in members_to_delete:
             member_info = member.split('_')
-            member_ip, member_port, subnet_id = (
+            member_ip, member_port, subnet_id, member_id = (
                 self._ovn_helper._extract_member_info(member)[0])
             request_info = {'id': member_info[1],
                             'address': member_ip,
@@ -429,12 +417,6 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
         for request in request_list:
             self._ovn_helper.add_request(request)
-        if skipped_members:
-            msg = (_('OVN provider does not support monitor options, '
-                     'so following members skipped: %s') % skipped_members)
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
 
     def create_vip_port(self, lb_id, project_id, vip_dict):
         try:
@@ -510,7 +492,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def health_monitor_delete(self, healthmonitor):
-        request_info = {'id': healthmonitor.healthmonitor_id}
+        request_info = {'id': healthmonitor.healthmonitor_id,
+                        'pool_id': healthmonitor.pool_id}
         request = {'type': ovn_const.REQ_TYPE_HM_DELETE,
                    'info': request_info}
         self._ovn_helper.add_request(request)
