@@ -355,8 +355,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up,
-                'subnet_id': self.ref_member.subnet_id}
+                'old_admin_state_up': self.ref_member.admin_state_up}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         self.driver.member_update(self.ref_member, self.update_member)
@@ -370,8 +369,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up,
-                'subnet_id': self.ref_member.subnet_id}
+                'old_admin_state_up': self.ref_member.admin_state_up}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -387,8 +385,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'address': self.ref_member.address,
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
-                'old_admin_state_up': self.ref_member.admin_state_up,
-                'subnet_id': self.ref_member.subnet_id}
+                'old_admin_state_up': self.ref_member.admin_state_up}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -407,6 +404,22 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                                         [self.ref_member, self.update_member])
         self.assertEqual(self.mock_add_request.call_count, 3)
 
+    def test_member_batch_update_member_delete(self):
+        info_md = {
+            'id': self.ref_member.member_id,
+            'address': mock.ANY,
+            'protocol_port': mock.ANY,
+            'pool_id': self.ref_member.pool_id,
+            'subnet_id': self.ref_member.subnet_id}
+        expected_dict_md = {
+            'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
+            'info': info_md}
+        expected = [
+            mock.call(expected_dict_md)]
+        self.driver.member_batch_update(self.pool_id, [])
+        self.assertEqual(self.mock_add_request.call_count, 1)
+        self.mock_add_request.assert_has_calls(expected)
+
     def test_member_batch_update_no_members(self):
         pool_key = 'pool_%s' % self.pool_id
         ovn_lb = copy.copy(self.ovn_lb)
@@ -435,6 +448,26 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.member_batch_update(self.pool_id, [self.ref_member])
         self.assertEqual(self.mock_add_request.call_count, 2)
 
+    def test_member_batch_update_toggle_admin_state_up(self):
+        info_mu = {
+            'id': self.ref_member.member_id,
+            'address': self.member_address,
+            'protocol_port': self.member_port,
+            'pool_id': self.ref_member.pool_id,
+            'subnet_id': self.ref_member.subnet_id,
+            'admin_state_up': False}
+        expected_dict_mu = {
+            'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
+            'info': info_mu}
+        expected = [
+            mock.call(expected_dict_mu)]
+        self.ref_member.admin_state_up = False
+        self.ref_member.address = self.member_address
+        self.ref_member.protocol_port = self.member_port
+        self.driver.member_batch_update(self.pool_id, [self.ref_member])
+        self.assertEqual(self.mock_add_request.call_count, 1)
+        self.mock_add_request.assert_has_calls(expected)
+
     def test_member_batch_update_missing_subnet_id(self):
         self.ref_member.subnet_id = None
         self.assertRaises(exceptions.UnsupportedOptionError,
@@ -870,24 +903,31 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.pool_delete(self.ref_pool)
         self.mock_add_request.assert_called_once_with(expected)
 
-    def test_pool_delete_with_members(self):
+    def test_pool_delete_with_members_and_hm(self):
+        self.ref_pool.healthmonitor = self.ref_health_monitor
         info = {'id': self.ref_pool.pool_id,
                 'protocol': self.ref_pool.protocol,
                 'loadbalancer_id': self.ref_pool.loadbalancer_id}
         expected = {'type': ovn_const.REQ_TYPE_POOL_DELETE,
                     'info': info}
+        info_hm = {'id': self.ref_pool.healthmonitor.healthmonitor_id,
+                   'pool_id': self.ref_pool.pool_id}
         info_member = {'id': self.ref_member.member_id,
                        'pool_id': self.ref_member.pool_id,
                        'subnet_id': self.ref_member.subnet_id,
                        'protocol_port': self.ref_member.protocol_port,
                        'address': self.ref_member.address}
+        expected_hm = {
+            'type': ovn_const.REQ_TYPE_HM_DELETE,
+            'info': info_hm}
         expected_members = {
             'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
             'info': info_member}
         expected_members_dvr = {
             'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
             'info': mock.ANY}
-        calls = [mock.call(expected_members),
+        calls = [mock.call(expected_hm),
+                 mock.call(expected_members),
                  mock.call(expected_members_dvr),
                  mock.call(expected)]
         self.driver.pool_delete(self.ref_pool)
@@ -1043,7 +1083,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.mock_add_request.assert_called_once_with(expected_dict)
 
     def test_health_monitor_delete(self):
-        info = {'id': self.ref_health_monitor.healthmonitor_id}
+        info = {'id': self.ref_health_monitor.healthmonitor_id,
+                'pool_id': self.ref_health_monitor.pool_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_HM_DELETE,
                          'info': info}
         self.driver.health_monitor_delete(self.ref_health_monitor)
